@@ -249,7 +249,7 @@ func (c *Client) ApplyConfiguration(ctx context.Context, req *machineapi.ApplyCo
 
 // GenerateConfiguration implements proto.MachineServiceClient interface.
 func (c *Client) GenerateConfiguration(ctx context.Context, req *machineapi.GenerateConfigurationRequest, callOptions ...grpc.CallOption) (resp *machineapi.GenerateConfigurationResponse, err error) {
-	resp, err = c.MachineClient.GenerateConfiguration(ctx, req, callOptions...)
+	resp, err = c.MachineClient.GenerateConfiguration(ctx, req, callOptions...) //nolint:staticcheck
 
 	return FilterMessages(resp, err)
 }
@@ -299,7 +299,7 @@ func (c *Client) Restart(ctx context.Context, namespace string, driver common.Co
 		_, err = FilterMessages(resp, err)
 	}
 
-	return
+	return err
 }
 
 // Reset implements the proto.MachineServiceClient interface.
@@ -309,7 +309,7 @@ func (c *Client) Reset(ctx context.Context, graceful, reboot bool) (err error) {
 		_, err = FilterMessages(resp, err)
 	}
 
-	return
+	return err
 }
 
 // ResetGeneric implements the proto.MachineServiceClient interface.
@@ -337,6 +337,11 @@ func WithPowerCycle(req *machineapi.RebootRequest) {
 	req.Mode = machineapi.RebootRequest_POWERCYCLE
 }
 
+// WithForce option runs the Reboot fun in force mode.
+func WithForce(req *machineapi.RebootRequest) {
+	req.Mode = machineapi.RebootRequest_FORCE
+}
+
 // Reboot implements the proto.MachineServiceClient interface.
 func (c *Client) Reboot(ctx context.Context, opts ...RebootMode) error {
 	_, err := c.RebootWithResponse(ctx, opts...)
@@ -366,7 +371,7 @@ func (c *Client) Rollback(ctx context.Context) (err error) {
 		_, err = FilterMessages(resp, err)
 	}
 
-	return
+	return err
 }
 
 // Bootstrap implements the proto.MachineServiceClient interface.
@@ -376,7 +381,7 @@ func (c *Client) Bootstrap(ctx context.Context, req *machineapi.BootstrapRequest
 		_, err = FilterMessages(resp, err)
 	}
 
-	return
+	return err
 }
 
 // ShutdownOption provides shutdown API options.
@@ -430,7 +435,7 @@ func (c *Client) Logs(ctx context.Context, namespace string, driver common.Conta
 		TailLines: tailLines,
 	})
 
-	return
+	return stream, err
 }
 
 // LogsContainers implements the proto.MachineServiceClient interface.
