@@ -43,6 +43,7 @@ type LaunchConfig struct {
 	ExtraISOPath              string
 	PFlashImages              []string
 	KernelArgs                string
+	SDStubKernelArgs          string
 	MonitorPath               string
 	DefaultBootOrder          string
 	BootloaderEnabled         bool
@@ -458,6 +459,10 @@ func patchKernelArgs(config *LaunchConfig, httpServerAddr net.Addr) error {
 
 	config.sdStubExtraCmdline = "console=ttyS0"
 
+	if config.SDStubKernelArgs != "" {
+		config.sdStubExtraCmdline += " " + config.SDStubKernelArgs
+	}
+
 	if strings.Contains(config.KernelArgs, "{TALOS_CONFIG_URL}") {
 		config.KernelArgs = strings.ReplaceAll(config.KernelArgs, "{TALOS_CONFIG_URL}", fmt.Sprintf("http://%s/config.yaml", configServerAddr))
 		config.sdStubExtraCmdlineConfig = fmt.Sprintf(" talos.config=http://%s/config.yaml", httpServerAddr)
